<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// We can't rely on Wordpress session management 
// as we also need sessions when there's no user available
if ( !session_id() ) { 
    session_start(); 
}

function vs_paperknife_kill_custom_session() {
    session_destroy();
}
add_action('wp_logout', 'vs_paperknife_kill_custom_session');
add_action('wp_login', 'vs_paperknife_kill_custom_session');

function vs_wp_mail( $args ) {
    // Set transient value containing the mail message body by session_id
    // When multiple messages are send in a loop we queue them up as an array
    // When the preview window is opened the queue is popped and cleared (see below). 
    // Queue management is fully done on the server side, the fronted has 
    // no queue knowledge.
    $current_transient = get_transient( 'vs_inbrowser_mail-'.session_id() );
    if ( $current_transient ) {
        array_push($current_transient, $args);
        set_transient( 'vs_inbrowser_mail-'.session_id(), $current_transient, 60 * 60 );

    } 
    else {
        set_transient( 'vs_inbrowser_mail-'.session_id(), array($args), 60 * 60 );				
    }
    
    return $args;
}
add_filter( 'wp_mail', 'vs_wp_mail' );

function vs_wp_inbrowser_mail_opener() {
    // Start the mail preview poller
    // Include page template (contains js poller)
    require_once( plugin_dir_path( __FILE__ ) . '../templates/vs_wp_inbrowser_js_poller.tmpl.php');
}	
add_action('wp_footer', 'vs_wp_inbrowser_mail_opener');

// Ajax poller to check if there's mail send for the current session_id
function vs_mailpreview_poller() {
    $value = get_transient( 'vs_inbrowser_mail-'.session_id() );
    return wp_send_json(array( "preview_mail" => $value, "s" => session_id() ));
}
if ( is_admin() ) {
    // Admin
    add_action('wp_ajax_vs_mailpreview_poller', 'vs_mailpreview_poller');

} else {
    // Viewer-Facing and not logged in 
    add_action('wp_ajax_nopriv_vs_mailpreview_poller', 'vs_mailpreview_poller');
}

// This renders the email out in a browser window
function vs_inbrowser_mail_preview() {
    if ($_SERVER["REQUEST_URI"] == '/vs_inbrowser_mail_preview') {

        $current_transient = get_transient( 'vs_inbrowser_mail-'.session_id() );
        $wp_mail = false;
        if ( $current_transient ) { 

            // This block is responsible for popping and clearing the queue 
            $wp_mail = array_pop($current_transient);
            if ( sizeof($current_transient) > 0 ) { 
                set_transient( 'vs_inbrowser_mail-'.session_id(), $current_transient, 60 * 60 );    
            } 
            else {
                delete_transient( 'vs_inbrowser_mail-'.session_id() );
            }

        }

        if ( $wp_mail ) {
            // Include page template
            include( plugin_dir_path( __FILE__ ) . '../templates/vs_wp_inbrowser_mail_preview.tmpl.php');
        }
        else {
            echo "No email found. Nothing to see here, move on!";
        }
        
        // Stop the Wordpress chain
        exit();
    }
}
add_action('parse_request', 'vs_inbrowser_mail_preview');
