<?php
/**
 * Plugin Name:     Paperknife
 * Plugin URI:      https://vicinitysoftware.com/paperknife
 * Description:     Preview all Wordpress generated emails in-browser so you don't have to wait and check your email in order to test and verify changes.
 * Author:          Thomas Cremers
 * Author URI:      https://vicinitysoftware.com
 * Text Domain:     paperknife
 * Domain Path:     /languages
 * Version:         0.1.3
 *
 * @package         Paperknife
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Plugin init logic
function vs_paperknife_init() {
    // Default settings after plugin install
    update_option( 'vs_mail_opener_plugin_enable', false );   
    update_option( 'vs_mail_opener_admin_only', 'on' );   
    update_option( 'vs_mail_opener_disable_outgoing_mail', false);

    // Show initial instruction messages after plugin is enabled
    update_option( 'vs_paperknife_init_message', true);
}
register_activation_hook( __FILE__, 'vs_paperknife_init' );

// Backend logic admin settings page
if ( is_admin() ) {
    require_once( plugin_dir_path( __FILE__ ) . 'lib/backend.php' );
}

// Frontend logic, mail detection poller. Only run this after wp init as we need to check permissions
function vs_paperknife_wordpress_init() {
    if ( vs_paperknife_should_enable_plugin() ) {
        
        // replace standard WordPress wp_mail() if nobody else has already done it
        // and if the option disable_outgoing_mail is enabled
        if ( 
            ( get_option('vs_mail_opener_disable_outgoing_mail') === 'on' ) && 
            !function_exists('wp_mail')         
            ) {

            function wp_mail( $to, $subject, $message, $headers = '', $attachments = array() ) { 
                // Skip all mail parsing but still call the filter which we catch in this plugin
                error_log( $subject );
                apply_filters( 'wp_mail', compact( 'to', 'subject', 'message', 'headers', 'attachments' ) );   
                return true; // end on a positive note 
            }    

        }

        // Frontend mail poller 
        require_once( plugin_dir_path( __FILE__ ) . 'lib/frontend.php' );
    }
}
add_action('init','vs_paperknife_wordpress_init');

// Moved gue logic into its own function 
function vs_paperknife_should_enable_plugin() {
    // Is the plugin enabled
    if ( get_option( 'vs_mail_opener_plugin_enable' ) === 'on' ) {

        // Should we check if it's only enabled for admin users?
        if ( get_option('vs_mail_opener_admin_only') === 'on' ) {
            // Return true as the current user IS an administrator and we're checking for that
            return current_user_can('administrator');
        } else {
            return true; 
        }
        
    }
    return false;
}

// Show a notice when the plugin is first activated "go to blah blah to setup"
if ( get_option('vs_paperknife_init_message') ) {
    function vs_paperknife_plugin_notices() {
        ?>
        <div class="notice notice-success is-dismissible">
            <p>
                <?php _e('Go to <b>"Tools &rarr; Paperknife"</b> to setup Paperknife', 'paperknife' ); ?>
            </p>
        </div>
        <?php
    }
    add_action('admin_notices', 'vs_paperknife_plugin_notices');
    update_option( 'vs_paperknife_init_message', false);
}

// Show a persistent warning when this Paperknife is enabled
if ( get_option('vs_mail_opener_plugin_enable') === 'on' ) {
    function vs_paperknife_plugin_enabled_warning() {
        ?>
        <div class="notice notice-warning is-dismissible">
            <p>
                <?php _e('<b>Warning: </b>Paperknife is enabled! Go to <b>"Tools &rarr; Paperknife"</b> if you want to disable it.', 'paperknife' ); ?>
            </p>
        </div>
        <?php
    }
    add_action('admin_notices', 'vs_paperknife_plugin_enabled_warning');
}
